/* @(#) $Id: gif.h 287 2017-01-21 19:15:36Z leres $ (XSE) */
#ifndef gif_h
#define gif_h

#define GIF_WIDTH(p) ((int)(p)->w2 * 256 + (int)(p)->w1)
#define GIF_HEIGHT(p) ((int)(p)->h2 * 256 + (int)(p)->h1)

struct gifheader {
	char magic[6];
	u_char w1, w2;
	u_char h1, h2;
};

int parsegif(const char *, int *, int *, struct timespec *);
#endif
